# Test and Benchmarking

The benchmarking script requires a KyTea's model. Run the following commands to download a model, decompress, and put into the specified directory:
```
$ wget http://www.phontron.com/kytea/download/model/jp-0.4.7-5.mod.gz
$ gunzip jp-0.4.7-5.mod.gz
$ mv jp-0.4.7-5.mod data/jp-0.4.7-5.mod
```
